@@ -30,6 +30,7 @@
 */
 
 #include <config.h>
+#include <string.h>
 
 #include "htmlsearch.h"
 #include "htmlobject.h"
@@ -39,8 +40,8 @@
 static void
 set_text (HTMLSearch *s, const gchar *text)
 {
-	s->text           = g_strdup (text);
-	s->text_len       = g_utf8_strlen (text, -1);
+	s->text = g_strdup (text);
+	s->text_bytes = strlen (text);
 }
 
 HTMLSearch *
@@ -59,7 +60,10 @@ html_search_new (HTMLEngine *e, const gchar *text, gboolean case_sensitive, gboo
 		HTMLObject *o;
  
 		ns->stack = NULL;
-		ns->start_pos = e->cursor->offset - 1;
+		if (ns->start_pos >= 0 )
+			ns->start_pos = e->cursor->offset - 1;
+		else
+			ns->start_pos = 0;
 		for (o = e->cursor->object; o; o = o->parent)
 			html_search_push (ns, o);
 		ns->stack = g_slist_reverse (ns->stack);
@@ -91,7 +95,7 @@ html_search_new (HTMLEngine *e, const gchar *text, gboolean case_sensitive, gboo
 		ns->reb = g_new0 (regex_t, 1);
 
 		ns->reb->translate = ns->trans;
-		rv = re_compile_pattern (ns->text, ns->text_len, ns->reb);
+		rv = re_compile_pattern (ns->text, ns->text_bytes, ns->reb);
 		if (rv) {
 			g_warning (rv);
 		}
